changeset 4206:703d3208424c kallithea-2.2.5-rebrand

Rename various strings for tests
author Bradley M. Kuhn <bkuhn@sfconservancy.org>
date Wed, 02 Jul 2014 19:05:41 -0400
parents 5b3bbffea092
children 58e390e0cea4
files .travis.yml docs/contributing.rst kallithea/config/environment.py kallithea/tests/__init__.py kallithea/tests/api/api_base.py kallithea/tests/fixtures/journal_dump.csv kallithea/tests/functional/test_admin.py kallithea/tests/other/test_vcs_operations.py kallithea/tests/scripts/test_crawler.py test.ini tox.ini
diffstat 11 files changed, 46 insertions(+), 158 deletions(-) [+]
line wrap: on
line diff
--- a/.travis.yml	Wed Jul 02 19:05:36 2014 -0400
+++ b/.travis.yml	Wed Jul 02 19:05:41 2014 -0400
@@ -5,9 +5,9 @@
   - "2.7"
 
 env:  
-  - TEST_DB=sqlite:////tmp/rhodecode_test.sqlite
-  - TEST_DB=mysql://root@127.0.0.1/rhodecode_test
-  - TEST_DB=postgresql://postgres@127.0.0.1/rhodecode_test
+  - TEST_DB=sqlite:////tmp/kallithea_test.sqlite
+  - TEST_DB=mysql://root@127.0.0.1/kallithea_test
+  - TEST_DB=postgresql://postgres@127.0.0.1/kallithea_test
 
 services:
   - mysql
@@ -15,8 +15,8 @@
 
 # command to install dependencies
 before_script:
-  - mysql -e 'create database rhodecode_test;'
-  - psql -c 'create database rhodecode_test;' -U postgres
+  - mysql -e 'create database kallithea_test;'
+  - psql -c 'create database kallithea_test;' -U postgres
   - git --version
 
 before_install:
--- a/docs/contributing.rst	Wed Jul 02 19:05:36 2014 -0400
+++ b/docs/contributing.rst	Wed Jul 02 19:05:41 2014 -0400
@@ -41,7 +41,7 @@
 There's a special set of tests for push/pull operations, you can runn them using::
 
     paster serve test.ini --pid-file=test.pid --daemon
-    RC_WHOOSH_TEST_DISABLE=1 RC_NO_TMP_PATH=1 nosetests -x kallithea/tests/other/test_vcs_operations.py
+    KALLITHEA_WHOOSH_TEST_DISABLE=1 KALLITHEA_NO_TMP_PATH=1 nosetests -x kallithea/tests/other/test_vcs_operations.py
     kill -9 $(cat test.pid)
 
 
--- a/kallithea/tests/__init__.py	Wed Jul 02 19:05:36 2014 -0400
+++ b/kallithea/tests/__init__.py	Wed Jul 02 19:05:41 2014 -0400
@@ -28,8 +28,8 @@
 nosetests --with-coverage --cover-package=kallithea.model.validators kallithea.tests.test_validators
 
 optional FLAGS:
-    RC_WHOOSH_TEST_DISABLE=1 - skip whoosh index building and tests
-    RC_NO_TMP_PATH=1 - disable new temp path for tests, used mostly for test_vcs_operations
+    KALLITHEA_WHOOSH_TEST_DISABLE=1 - skip whoosh index building and tests
+    KALLITHEA_NO_TMP_PATH=1 - disable new temp path for tests, used mostly for test_vcs_operations
 
 """
 import os
--- a/kallithea/tests/api/api_base.py	Wed Jul 02 19:05:36 2014 -0400
+++ b/kallithea/tests/api/api_base.py	Wed Jul 02 19:05:41 2014 -0400
@@ -15,7 +15,7 @@
 """
 tests for api. run with::
 
-    RC_WHOOSH_TEST_DISABLE=1 nosetests --with-coverage --cover-package=kallithea.controllers.api.api -x kallithea/tests/api
+    KALLITHEA_WHOOSH_TEST_DISABLE=1 nosetests --with-coverage --cover-package=kallithea.controllers.api.api -x kallithea/tests/api
 """
 
 from __future__ import with_statement
--- a/kallithea/tests/fixtures/journal_dump.csv	Wed Jul 02 19:05:36 2014 -0400
+++ b/kallithea/tests/fixtures/journal_dump.csv	Wed Jul 02 19:05:41 2014 -0400
@@ -197,11 +197,11 @@
 245,43,lpyedge,56,brgit,"",started_following_repo,2012-07-12 15:18:17.687605
 246,43,lpyedge,56,brgit,"",user_created_repo,2012-07-12 15:18:17.702136
 247,1,default,34,a,54.247.183.89,pull,2012-07-12 16:53:15.165512
-248,45,krhodecode,1,test,"",user_commented_revision:ef02269209cd431c0cd0ee929ba37ae895651d69,2012-07-12 23:09:25.38717
-249,45,krhodecode,42,foo,"",user_commented_revision:ca953e8c5c1ada44e9a8f945a0a6999d2f44310d,2012-07-12 23:14:07.819338
-250,45,krhodecode,57,SuperProject,"",started_following_repo,2012-07-12 23:17:38.213634
-251,45,krhodecode,57,SuperProject,"",user_created_repo,2012-07-12 23:17:38.229359
-252,45,krhodecode,57,SuperProject,216.51.137.66,push:a3188ce9ed64822ceae497665910c2e18cddf021,2012-07-12 23:23:23.111788
+248,45,kxxx,1,test,"",user_commented_revision:ef02269209cd431c0cd0ee929ba37ae895651d69,2012-07-12 23:09:25.38717
+249,45,kxxx,42,foo,"",user_commented_revision:ca953e8c5c1ada44e9a8f945a0a6999d2f44310d,2012-07-12 23:14:07.819338
+250,45,kxxx,57,SuperProject,"",started_following_repo,2012-07-12 23:17:38.213634
+251,45,kxxx,57,SuperProject,"",user_created_repo,2012-07-12 23:17:38.229359
+252,45,kxxx,57,SuperProject,216.51.137.66,push:a3188ce9ed64822ceae497665910c2e18cddf021,2012-07-12 23:23:23.111788
 253,3,demo,38,code-review-test,"",user_commented_revision:fba17a64fa4978bfea19222da5e64a18cfddeecd,2012-07-13 14:22:00.003158
 254,46,snazy2000,58,group/Test,"",started_following_repo,2012-07-13 19:14:31.959033
 255,46,snazy2000,58,group/Test,"",user_created_repo,2012-07-13 19:14:31.972509
@@ -611,10 +611,10 @@
 659,3,demo,132,test-alex,"",push_local:807dd6bb60f5eef82f7ffdd988dee3e0de4e44dc,2012-08-13 21:26:51.764858
 660,3,demo,132,test-alex,"",push_local:24224f94a8578508883f58982e10b0ffa83a98d6,2012-08-13 21:28:03.831471
 661,3,demo,42,foo,"",user_commented_revision:ca953e8c5c1ada44e9a8f945a0a6999d2f44310d,2012-08-14 18:40:46.618059
-662,118,peso-rhodecode,99,another-fork-to-check-code-review,"",user_commented_revision:30853f4bde2f2b6f0a7126392b9b1b4c5ea37e0a,2012-08-14 18:58:56.536013
-663,118,peso-rhodecode,99,another-fork-to-check-code-review,"",user_commented_revision:30853f4bde2f2b6f0a7126392b9b1b4c5ea37e0a,2012-08-14 18:59:58.982696
-664,118,peso-rhodecode,133,tortoisehg,"",started_following_repo,2012-08-14 19:05:14.873877
-665,118,peso-rhodecode,133,tortoisehg,"",user_created_repo,2012-08-14 19:05:14.88921
+662,118,peso-xxx,99,another-fork-to-check-code-review,"",user_commented_revision:30853f4bde2f2b6f0a7126392b9b1b4c5ea37e0a,2012-08-14 18:58:56.536013
+663,118,peso-xxx,99,another-fork-to-check-code-review,"",user_commented_revision:30853f4bde2f2b6f0a7126392b9b1b4c5ea37e0a,2012-08-14 18:59:58.982696
+664,118,peso-xxx,133,tortoisehg,"",started_following_repo,2012-08-14 19:05:14.873877
+665,118,peso-xxx,133,tortoisehg,"",user_created_repo,2012-08-14 19:05:14.88921
 666,119,ricardona,39,fork-code-review-test,"",user_commented_revision:ac19ef61aab0b008acb5dac5d53457cbd278d927,2012-08-14 21:20:28.585574
 667,3,demo,134,TestIM,"",started_following_repo,2012-08-14 22:23:05.22279
 668,3,demo,134,TestIM,"",user_created_repo,2012-08-14 22:23:05.235172
@@ -756,10 +756,10 @@
 807,3,demo,159,group/Test-for-code-review,"",user_commented_revision:2305443e5a06a9d80e328741d2da742145f80eee,2012-08-30 19:15:23.722829
 808,150,dlamotte,1,test,"",user_commented_pull_request:31,2012-08-30 23:03:25.180892
 809,150,dlamotte,1,test,"",user_closed_pull_request:31,2012-08-30 23:03:25.192118
-810,150,dlamotte,161,test-rhodecode-pull-request,"",started_following_repo,2012-08-30 23:05:08.817245
-811,150,dlamotte,161,test-rhodecode-pull-request,"",user_created_repo,2012-08-30 23:05:08.832769
-812,150,dlamotte,161,test-rhodecode-pull-request,143.127.128.10,push:e839aac4f06bb1f0dde813d6b7e80cc345f8d70d,2012-08-30 23:06:12.300969
-813,150,dlamotte,161,test-rhodecode-pull-request,143.127.128.10,"push:1b01a9f3ba4951615f1c9cfbe19ea62f3abeed9f,062ab363eaef7fc73342a93f4624030103fc36f9",2012-08-30 23:08:29.621962
+810,150,dlamotte,161,test-xxx-pull-request,"",started_following_repo,2012-08-30 23:05:08.817245
+811,150,dlamotte,161,test-xxx-pull-request,"",user_created_repo,2012-08-30 23:05:08.832769
+812,150,dlamotte,161,test-xxx-pull-request,143.127.128.10,push:e839aac4f06bb1f0dde813d6b7e80cc345f8d70d,2012-08-30 23:06:12.300969
+813,150,dlamotte,161,test-xxx-pull-request,143.127.128.10,"push:1b01a9f3ba4951615f1c9cfbe19ea62f3abeed9f,062ab363eaef7fc73342a93f4624030103fc36f9",2012-08-30 23:08:29.621962
 814,1,default,1,test,176.9.28.203,pull,2012-08-30 23:14:51.336754
 815,151,mill1359,162,test-m,"",started_following_repo,2012-08-30 23:14:51.499881
 816,151,mill1359,162,test-m,"",user_created_repo,2012-08-30 23:14:51.509169
@@ -772,13 +772,13 @@
 895,3,demo,122,amab,"",push_local:f0509a4f718f5a31eafcb8fbe9caf21a642c5753,2012-09-05 01:30:02.737976
 896,3,demo,32,big-project,"",user_commented_revision:06d5302c4830e5af52f06c462f11f75107b2a1ff,2012-09-05 11:05:19.904842
 823,155,cdugz,163,nagios,82.150.248.28,"push:380d5c3fd6c3948d5da3f56859104f4adf629553,30b5773f0f9d57cfb721576169685b36878969d1,47deef50eface398daa8ba09a6d79a9db2585c4f,a38d5508f516f360cd603a72cd4a4f16facf5825,cf7656e6c2cb29241db1f6ae0af2823684d7d0b4,0ebf06f94b584abe59853618ca68b9416f13fe20,413886edff138d8de1e3e23698fabba444de6167,335bb28b7c5428044f17ef9bc57a992b759b2d93,feba8837f9ac8af56b6588e8fcc7710eeeebd327,bf0781be32a59aef35f8bf95a2f614894e773926,fc3792349c770fe014d0774e980e3bba600bb5a6",2012-08-31 16:46:05.896127
-824,155,cdugz,164,rhodecode-ref,"",started_following_repo,2012-08-31 17:42:24.794235
-825,155,cdugz,164,rhodecode-ref,"",user_created_repo,2012-08-31 17:42:24.806839
-826,155,cdugz,164,rhodecode-ref,82.150.248.28,"push:380d5c3fd6c3948d5da3f56859104f4adf629553,30b5773f0f9d57cfb721576169685b36878969d1,47deef50eface398daa8ba09a6d79a9db2585c4f,c91bea8206218cf051c6b0ab6a352c7371b5212d",2012-08-31 17:43:03.365708
-827,155,cdugz,164,rhodecode-ref,"",user_updated_repo,2012-08-31 17:44:01.673127
-828,155,cdugz,165,rhodecode-dev,"",started_following_repo,2012-08-31 17:44:52.870468
-829,155,cdugz,165,rhodecode-dev,"",user_created_repo,2012-08-31 17:44:52.880649
-830,155,cdugz,165,rhodecode-dev,82.150.248.28,"push:380d5c3fd6c3948d5da3f56859104f4adf629553,30b5773f0f9d57cfb721576169685b36878969d1,47deef50eface398daa8ba09a6d79a9db2585c4f,107236f51ef01fcb27d1c613c18a93a2135c336c,2ff774f5163960e356530826b4faad804bd79972,e4b37340f046c2910a43017d814841df1caec1cf,c91bea8206218cf051c6b0ab6a352c7371b5212d,3e5071670c8eec699744bd94f9ebacba8ef33b1f,06303e4e0da2b0e909d985844fc573e3a32547a2",2012-08-31 17:45:20.027085
+824,155,cdugz,164,xxx-ref,"",started_following_repo,2012-08-31 17:42:24.794235
+825,155,cdugz,164,xxx-ref,"",user_created_repo,2012-08-31 17:42:24.806839
+826,155,cdugz,164,xxx-ref,82.150.248.28,"push:380d5c3fd6c3948d5da3f56859104f4adf629553,30b5773f0f9d57cfb721576169685b36878969d1,47deef50eface398daa8ba09a6d79a9db2585c4f,c91bea8206218cf051c6b0ab6a352c7371b5212d",2012-08-31 17:43:03.365708
+827,155,cdugz,164,xxx-ref,"",user_updated_repo,2012-08-31 17:44:01.673127
+828,155,cdugz,165,xxx-dev,"",started_following_repo,2012-08-31 17:44:52.870468
+829,155,cdugz,165,xxx-dev,"",user_created_repo,2012-08-31 17:44:52.880649
+830,155,cdugz,165,xxx-dev,82.150.248.28,"push:380d5c3fd6c3948d5da3f56859104f4adf629553,30b5773f0f9d57cfb721576169685b36878969d1,47deef50eface398daa8ba09a6d79a9db2585c4f,107236f51ef01fcb27d1c613c18a93a2135c336c,2ff774f5163960e356530826b4faad804bd79972,e4b37340f046c2910a43017d814841df1caec1cf,c91bea8206218cf051c6b0ab6a352c7371b5212d,3e5071670c8eec699744bd94f9ebacba8ef33b1f,06303e4e0da2b0e909d985844fc573e3a32547a2",2012-08-31 17:45:20.027085
 831,3,demo,93,fork-a,"",push_local:416552904882d8b8f051cad2071f4aa271d4ea4e,2012-08-31 18:50:50.885869
 832,3,demo,166,dfgdfg,"",started_following_repo,2012-08-31 18:56:16.94572
 833,3,demo,166,dfgdfg,"",user_created_repo,2012-08-31 18:56:16.959102
@@ -872,7 +872,7 @@
 923,3,demo,34,a,"",user_closed_pull_request:38,2012-09-05 13:41:51.082763
 924,3,demo,34,a,"",user_updated_repo,2012-09-05 13:42:28.045216
 925,3,demo,176,hopsa,"",started_following_repo,2012-09-05 14:12:14.479866
-926,3,demo,165,rhodecode-dev,"",user_forked_repo:hopsa,2012-09-05 14:12:14.495649
+926,3,demo,165,xxx-dev,"",user_forked_repo:hopsa,2012-09-05 14:12:14.495649
 927,3,demo,176,hopsa,"",user_created_fork:hopsa,2012-09-05 14:12:14.507312
 928,3,demo,177,blah,"",started_following_repo,2012-09-05 16:42:29.860682
 929,3,demo,177,blah,"",user_created_repo,2012-09-05 16:42:29.876509
@@ -933,8 +933,8 @@
 984,3,demo,189,fork-_01_jdj,"",started_following_repo,2012-09-07 22:55:46.169783
 985,3,demo,170,_01_jdj,"",user_forked_repo:fork-_01_jdj,2012-09-07 22:55:46.191342
 986,3,demo,189,fork-_01_jdj,"",user_created_fork:fork-_01_jdj,2012-09-07 22:55:46.209143
-987,2,admin,190,rhodecode,"",started_following_repo,2012-09-08 01:07:09.881091
-988,2,admin,190,rhodecode,"",admin_created_repo,2012-09-08 01:07:09.895097
+987,2,admin,190,xxx,"",started_following_repo,2012-09-08 01:07:09.881091
+988,2,admin,190,xxx,"",admin_created_repo,2012-09-08 01:07:09.895097
 989,3,demo,34,a,"",user_commented_revision:332932afc11a2c6308d44e75f8b4ac7643093fa7,2012-09-08 08:57:27.586796
 990,3,demo,191,kekeke,"",started_following_repo,2012-09-08 11:22:58.159504
 991,3,demo,191,kekeke,"",user_created_repo,2012-09-08 11:22:58.175212
@@ -1708,7 +1708,7 @@
 1769,2,admin,339,releases/test123,146.48.87.66,push:87e9dcd8d3e375c218fdb747da52dc1551a93dc7,2012-10-24 14:12:02.63513
 1770,292,Airframe,340,Testtestac,"",started_following_repo,2012-10-24 17:09:26.37836
 1771,292,Airframe,340,Testtestac,"",user_created_repo,2012-10-24 17:09:26.387917
-1772,293,imbehind,190,rhodecode,"",user_commented_revision:008d9c6f7c92636aaeda6f182bffecac6a464dd3,2012-10-24 20:38:59.535098
+1772,293,imbehind,190,xxx,"",user_commented_revision:008d9c6f7c92636aaeda6f182bffecac6a464dd3,2012-10-24 20:38:59.535098
 1773,3,demo,341,MicTest,"",started_following_repo,2012-10-24 20:59:34.176289
 1774,3,demo,341,MicTest,"",user_created_repo,2012-10-24 20:59:34.186308
 1775,3,demo,341,MicTest,"",push_local:327bf84d0d633a66f0c7ff4533de2415c9ff5a88,2012-10-24 21:00:28.379598
--- a/kallithea/tests/functional/test_admin.py	Wed Jul 02 19:05:36 2014 -0400
+++ b/kallithea/tests/functional/test_admin.py	Wed Jul 02 19:05:41 2014 -0400
@@ -62,13 +62,13 @@
     def test_filter_journal_filter_exact_match_on_repository(self):
         self.log_user()
         response = self.app.get(url(controller='admin/admin', action='index',
-                                    filter='repository:rhodecode'))
+                                    filter='repository:xxx'))
         response.mustcontain('3 entries')
 
     def test_filter_journal_filter_exact_match_on_repository_CamelCase(self):
         self.log_user()
         response = self.app.get(url(controller='admin/admin', action='index',
-                                    filter='repository:RhodeCode'))
+                                    filter='repository:XxX'))
         response.mustcontain('3 entries')
 
     def test_filter_journal_filter_wildcard_on_repository(self):
@@ -98,7 +98,7 @@
     def test_filter_journal_filter_prefix_on_repository_or_other_repo(self):
         self.log_user()
         response = self.app.get(url(controller='admin/admin', action='index',
-                                    filter='repository:test* OR repository:rhodecode'))
+                                    filter='repository:test* OR repository:xxx'))
         response.mustcontain('260 entries')  # 257 + 3
 
     def test_filter_journal_filter_exact_match_on_username(self):
--- a/kallithea/tests/other/test_vcs_operations.py	Wed Jul 02 19:05:36 2014 -0400
+++ b/kallithea/tests/other/test_vcs_operations.py	Wed Jul 02 19:05:41 2014 -0400
@@ -17,7 +17,7 @@
 
 Test suite for making push/pull operations.
 Run using after doing paster serve test.ini::
- RC_WHOOSH_TEST_DISABLE=1 RC_NO_TMP_PATH=1 nosetests kallithea/tests/other/test_vcs_operations.py
+ KALLITHEA_WHOOSH_TEST_DISABLE=1 KALLITHEA_NO_TMP_PATH=1 nosetests kallithea/tests/other/test_vcs_operations.py
 
 You must have git > 1.8.1 for tests to work fine
 
--- a/kallithea/tests/scripts/test_crawler.py	Wed Jul 02 19:05:36 2014 -0400
+++ b/kallithea/tests/scripts/test_crawler.py	Wed Jul 02 19:05:41 2014 -0400
@@ -62,14 +62,14 @@
 PROJECTS = [
     #'linux-magx-pbranch',
     'CPython',
-    'rhodecode_tip',
+    'kallithea',
 ]
 
 
 cj = cookielib.FileCookieJar('/tmp/rc_test_cookie.txt')
 o = urllib2.build_opener(urllib2.HTTPCookieProcessor(cj))
 o.addheaders = [
-    ('User-agent', 'rhodecode-crawler'),
+    ('User-agent', 'kallithea-crawler'),
     ('Accept-Language', 'en - us, en;q = 0.5')
 ]
 
--- a/test.ini	Wed Jul 02 19:05:36 2014 -0400
+++ b/test.ini	Wed Jul 02 19:05:41 2014 -0400
@@ -388,9 +388,9 @@
 #########################################################
 ### DB CONFIGS - EACH DB WILL HAVE IT'S OWN CONFIG    ###
 #########################################################
-sqlalchemy.db1.url = sqlite:///%(here)s/rhodecode_test.sqlite
-#sqlalchemy.db1.url = postgresql://postgres:qwe@localhost/rhodecode_test
-#sqlalchemy.db1.url = mysql://root:qwe@localhost/rhodecode_test
+sqlalchemy.db1.url = sqlite:///%(here)s/kallithea_test.sqlite
+#sqlalchemy.db1.url = postgresql://postgres:qwe@localhost/kallithea_test
+#sqlalchemy.db1.url = mysql://root:qwe@localhost/kallithea_test
 sqlalchemy.db1.echo = false
 sqlalchemy.db1.pool_recycle = 3600
 sqlalchemy.db1.convert_unicode = true
--- a/tox.ini	Wed Jul 02 19:05:36 2014 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,112 +0,0 @@
-[tox]
-envlist = py25-sqlite,
-          py25-mysql,
-          py25-postgresql,
-          py26-sqlite,
-          py26-mysql,
-          py26-postgresql,
-          py27-sqlite,
-          py27-mysql,
-          py27-postgresql
-
-
-#### PYTHON 2.5 ####
-[testenv:py25-sqlite]
-basepython =
-    python2.5
-commands =
-    nosetests []
-setenv =
-    TEST_DB=sqlite:////tmp/rhodecode_test.sqlite
-
-[testenv:py25-mysql]
-basepython =
-    python2.5
-commands =
-    mysql -uroot -pqwe -hlocalhost -e 'drop database if exists rhodecode_test;'
-    mysql -uroot -pqwe -hlocalhost -e 'create database rhodecode_test;'
-    nosetests []
-deps =
-    mysql-python
-setenv =
-    TEST_DB=mysql://root:qwe@localhost/rhodecode_test
-
-[testenv:py25-postgresql]
-basepython =
-    python2.5
-commands =
-    psql -Upostgres -Wqwe -hlocalhost -c 'drop database if exists rhodecode_test;'
-    psql -Upostgres -Wqwe -hlocalhost -c 'create database rhodecode_test;'
-    nosetests []
-deps =
-    psycopg2
-setenv =
-    TEST_DB=postgresql://postgres:qwe@localhost/rhodecode_test
-
-
-#### PYTHON 2.6 ####
-[testenv:py26-sqlite]
-basepython =
-    python2.6
-commands =
-    nosetests []
-setenv =
-    TEST_DB=sqlite:////tmp/rhodecode_test.sqlite
-
-[testenv:py26-mysql]
-basepython =
-    python2.6
-commands =
-    mysql -uroot -pqwe -hlocalhost -e 'drop database if exists rhodecode_test;'
-    mysql -uroot -pqwe -hlocalhost -e 'create database rhodecode_test;'
-    nosetests []
-deps =
-    mysql-python
-setenv =
-    TEST_DB=mysql://root:qwe@localhost/rhodecode_test
-
-[testenv:py26-postgresql]
-basepython =
-    python2.6
-commands =
-    psql -Upostgres -Wqwe -hlocalhost -c 'drop database if exists rhodecode_test;'
-    psql -Upostgres -Wqwe -hlocalhost -c 'create database rhodecode_test;'
-    nosetests []
-deps =
-    psycopg2
-setenv =
-    TEST_DB=postgresql://postgres:qwe@localhost/rhodecode_test
-
-
-#### PYTHON 2.7 ####
-[testenv:py27-sqlite]
-basepython =
-    python2.7
-commands =
-    nosetests []
-setenv =
-    TEST_DB=sqlite:////tmp/rhodecode_test.sqlite
-
-[testenv:py27-mysql]
-basepython =
-    python2.7
-commands =
-    mysql -uroot -pqwe -hlocalhost -e 'drop database if exists rhodecode_test;'
-    mysql -uroot -pqwe -hlocalhost -e 'create database rhodecode_test;'
-    nosetests []
-deps =
-    mysql-python
-setenv =
-    TEST_DB=mysql://root:qwe@localhost/rhodecode_test
-
-[testenv:py27-postgresql]
-basepython =
-    python2.7
-commands =
-    psql -Upostgres -Wqwe -hlocalhost -c 'drop database if exists rhodecode_test;'
-    psql -Upostgres -Wqwe -hlocalhost -c 'create database rhodecode_test;'
-    nosetests []
-deps =
-    psycopg2
-setenv =
-    TEST_DB=postgresql://postgres:qwe@localhost/rhodecode_test
--- a/kallithea/config/environment.py	Wed Jul 02 19:05:36 2014 -0400
+++ b/kallithea/config/environment.py	Wed Jul 02 19:05:41 2014 -0400
@@ -91,20 +91,20 @@
     test = os.path.split(config['__file__'])[-1] == 'test.ini'
     if test:
         if test_env is None:
-            test_env = not int(os.environ.get('RC_NO_TMP_PATH', 0))
+            test_env = not int(os.environ.get('KALLITHEA_NO_TMP_PATH', 0))
         if test_index is None:
-            test_index = not int(os.environ.get('RC_WHOOSH_TEST_DISABLE', 0))
+            test_index = not int(os.environ.get('KALLITHEA_WHOOSH_TEST_DISABLE', 0))
         if os.environ.get('TEST_DB'):
             # swap config if we pass enviroment variable
             config['sqlalchemy.db1.url'] = os.environ.get('TEST_DB')
 
         from kallithea.lib.utils import create_test_env, create_test_index
         from kallithea.tests import TESTS_TMP_PATH
         #set RC_NO_TMP_PATH=1 to disable re-creating the database and
         #test repos
         if test_env:
             create_test_env(TESTS_TMP_PATH, config)
         #set RC_WHOOSH_TEST_DISABLE=1 to disable whoosh index during tests
         if test_index:
             create_test_index(TESTS_TMP_PATH, config, True)
 
@@ -91,20 +91,20 @@
         from kallithea.lib.utils import create_test_env, create_test_index
         from kallithea.tests import TESTS_TMP_PATH
-        #set RC_NO_TMP_PATH=1 to disable re-creating the database and
+        #set KALLITHEA_NO_TMP_PATH=1 to disable re-creating the database and
         #test repos
         if test_env:
@@ -91,20 +91,20 @@
         if test_env:
             create_test_env(TESTS_TMP_PATH, config)
-        #set RC_WHOOSH_TEST_DISABLE=1 to disable whoosh index during tests
+        #set KALLITHEA_WHOOSH_TEST_DISABLE=1 to disable whoosh index during tests
         if test_index:
             create_test_index(TESTS_TMP_PATH, config, True)